"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _redux = require("redux");

var _reactRouterRedux = require("react-router-redux");

var _v = _interopRequireDefault(require("uuid/v4"));

var _create_view_models_reducer = _interopRequireDefault(require("./create_view_models_reducer"));

var _create_read_models_reducer = _interopRequireDefault(require("./create_read_models_reducer"));

var _create_jwt_reducer = _interopRequireDefault(require("./create_jwt_reducer"));

var _create_resolve_middleware = _interopRequireDefault(require("./create_resolve_middleware"));

var _sync_jwt_provider_with_store = _interopRequireDefault(require("./sync_jwt_provider_with_store"));

var createStore = function createStore(_ref) {
  var _ref$redux = _ref.redux,
      reducers = _ref$redux.reducers,
      middlewares = _ref$redux.middlewares,
      enhancers = _ref$redux.enhancers,
      customSagas = _ref$redux.sagas,
      viewModels = _ref.viewModels,
      readModels = _ref.readModels,
      aggregates = _ref.aggregates,
      subscribeAdapter = _ref.subscribeAdapter,
      initialState = _ref.initialState,
      history = _ref.history,
      origin = _ref.origin,
      rootPath = _ref.rootPath,
      jwtProvider = _ref.jwtProvider,
      isClient = _ref.isClient;
  var sessionId = (0, _v.default)();
  var resolveMiddleware = (0, _create_resolve_middleware.default)();
  var combinedReducers = (0, _redux.combineReducers)((0, _objectSpread2.default)({}, reducers, {
    router: _reactRouterRedux.routerReducer,
    viewModels: (0, _create_view_models_reducer.default)(viewModels),
    readModels: (0, _create_read_models_reducer.default)(readModels),
    jwt: (0, _create_jwt_reducer.default)()
  }));

  var appliedMiddlewares = _redux.applyMiddleware.apply(void 0, [(0, _reactRouterRedux.routerMiddleware)(history), resolveMiddleware].concat(middlewares));

  var composedEnhancers = _redux.compose.apply(void 0, [appliedMiddlewares].concat(enhancers));

  var store = (0, _redux.createStore)(combinedReducers, initialState, composedEnhancers);
  resolveMiddleware.run({
    store: store,
    viewModels: viewModels,
    readModels: readModels,
    aggregates: aggregates,
    origin: origin,
    rootPath: rootPath,
    subscribeAdapter: subscribeAdapter,
    sessionId: sessionId,
    jwtProvider: jwtProvider,
    isClient: isClient,
    customSagas: customSagas
  });
  (0, _sync_jwt_provider_with_store.default)(jwtProvider, store).catch( // eslint-disable-next-line no-console
  function (error) {
    return console.error(error);
  });
  return store;
};

var _default = createStore;
exports.default = _default;
//# sourceMappingURL=create_store.js.map